@@ -8,7 +8,7 @@ use File::Flat ();
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '0.06';	
+	$VERSION = '0.07';	
 }
 
 
@@ -90,11 +90,11 @@ For other issues, contact the author.
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>cpan@ali.asE<gt>, L<http://ali.as/>
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>, L<http://ali.as/>
 
 =head1 COPYRIGHT
 
-Copyright 2005 Adam Kennedy. All rights reserved.
+Copyright 2005 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
